package com.altinity.opsview.odw.reports.test;

import java.io.File;
import java.io.IOException;
import java.io.OutputStream;
import java.text.SimpleDateFormat;
import java.util.Calendar;
import java.util.Date;

import javax.xml.transform.Result;
import javax.xml.transform.Source;
import javax.xml.transform.Transformer;
import javax.xml.transform.TransformerException;
import javax.xml.transform.TransformerFactory;
import javax.xml.transform.stream.StreamResult;
import javax.xml.transform.stream.StreamSource;

import org.dom4j.Document;
import org.dom4j.DocumentHelper;
import org.dom4j.Element;

import com.altinity.opsview.odw.bc.ODWReportLogger;
import com.altinity.opsview.odw.bc.WeeklyServiceAvailabilityReportBC;
import com.altinity.opsview.odw.reports.ReportCriteria;
import com.excira.reports.ReportEngine;


public class TestXSL extends TestBase {
	
	/**
	 * 
	 */
	public void ntestLineFeedFO() {
		
		try {
			
			String currentDir = System.getProperty("user.dir");
			
			String xmlFilePath = currentDir + "/test/testAnno.xml";
			String xslFilePath = currentDir + "/test/testAnno.xsl";
			String foFilePath = currentDir + "/test/testAnno.fo";
			
			convertXML2FO(new File(xmlFilePath), new File(xslFilePath), new File(foFilePath));
		}
		catch(Exception e) {
			e.printStackTrace();
		}
	}
	
	/**
	 * 
	 */
	public void testLineFeedPDF() {
		
		try {
			
			Document doc = DocumentHelper.createDocument();
			Element reportEl = doc.addElement("report");
			Element testEl = reportEl.addElement("test");
			Element annoEl = testEl.addElement("annotation");
			annoEl.setText("testing\r\ncarriage\r\nreturn!");
			
			String currentDir = System.getProperty("user.dir");
			String xslFilePath = currentDir + "/test/testAnno.xsl";
			String outputFilePath = currentDir + "/test/testAnno.pdf";
			
			ReportEngine re = new ReportEngine();
			re.genratePDF(doc, xslFilePath, outputFilePath);
		}
		catch(Exception e) {
			e.printStackTrace();
		}
	}
	
	/**
	 * 
	 */
	public void convertXML2FO(File xml, File xslt, File fo) throws IOException, TransformerException {

		//Setup output
		OutputStream out = new java.io.FileOutputStream(fo);
		
		try {
			//Setup XSLT
			TransformerFactory factory = TransformerFactory.newInstance();
			Transformer transformer = factory.newTransformer(new StreamSource(xslt));
			
			//Setup input for XSLT transformation
			Source src = new StreamSource(xml);
			
			//Resulting SAX events (the generated FO) must be piped through to FOP
			Result res = new StreamResult(out);
			
			//Start XSLT transformation and FOP processing
			transformer.transform(src, res);
			
		} finally {
			
			out.close();
		}
	}
	
	/**
	 * 
	 */
	public void ntestXSL() {
		
		try {
			
			// Setup report criteria
			ReportCriteria rc = new ReportCriteria();
			rc.setReportId(2);
			rc.setReportName("Draft Report");
			rc.setReportType("Weekly Availability by Keyword, Critical States");
			rc.setFormat("US");
			rc.setFileFormat("jpeg");
			rc.setLabel("hostname/servicecheck");
			
			String currentDir = System.getProperty("user.dir");
			rc.setChartsRoot(currentDir + "/temp");
			
			SimpleDateFormat formatter = new SimpleDateFormat("yyyy-MM-dd");
			Date dataStartDate = formatter.parse("2007-11-05");
			rc.setReportStartDate(dataStartDate);
			
			Calendar cal = Calendar.getInstance();
			cal.setTime(dataStartDate);
			cal.add(Calendar.WEEK_OF_YEAR, 1);
			rc.setReportEndDate(cal.getTime());
		
			// Create document
			Document doc = DocumentHelper.createDocument();
			Element report = doc.addElement("report");
	
			report.addElement("title").setText(rc.getReportName());
			report.addElement("report-type").setText(rc.getReportType());
			
			// Determine the report format (page size)
			// Either A4 or US
			report.addAttribute("report-format", "report" + rc.getFormat());
			report.addAttribute("report-cover-format", "cover" + rc.getFormat());
			
			SimpleDateFormat dateFormatter = new SimpleDateFormat("yyyy-MM-dd");
			
			// Determine report start and end dates
			Date coverStartDate = rc.getReportStartDate();
			report.addElement("start-date").setText(dateFormatter.format(coverStartDate));
			
			Date coverEndDate = rc.getReportEndDate();
			report.addElement("end-date").setText(dateFormatter.format(coverEndDate));
			
			// Add run date
			report.addElement("run-date").setText(dateFormatter.format(Calendar.getInstance().getTime()));
			
			// Add sections
			report.addElement("report-sections");
			
			// Setup paths
			doc.getRootElement().addElement("charts-root").setText(rc.getChartsRoot());
			doc.getRootElement().addElement("asset-root").setText(currentDir + "/assets");
			doc.getRootElement().addElement("logo").setText("assets/opsview_436_100.gif");
			
			// Now add summary section
			WeeklyServiceAvailabilityReportBC bc = new WeeklyServiceAvailabilityReportBC();
			bc.setDocument(doc);
			bc.setLog(new ODWReportLogger());
			bc.setReportCriteria(rc);
			bc.setConfigDao(reportsDAO);
			bc.setDao(odwDAO);
			bc.createReport();
			
			// Add failure summary
			if ( !bc.getLog().isClean() )
					bc.createErrorsSummary();			
			
			ReportEngine re = new ReportEngine();
			String xslFilePath = currentDir + "/xsl/reports/WeeklyServiceAvailabilityReport.xsl";
		
			re.genratePDF(doc, xslFilePath, currentDir + "/reports/testXSL.pdf");
		}
		catch(Exception e) {
			e.printStackTrace();
			assertTrue(false);
			throw new RuntimeException(e);
		}
		
		System.out.println("The dishes are DONE man!");
	}
}
