package com.excira.utils;

import java.util.regex.Pattern;

/**
 * Copyright (C) 2008 Opsera Limited. All rights reserved
 *
 * This file is part of Opsview
 * 
 * Opsview is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * Opsview is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * 
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Opsview; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301  USA
 * 
 */

public class StringUtils {

	/****************************************************************************
	 * returns the substring after the delimeiter or the string if it does not
	 * contain the delimiter.
	 * 
	 * @param string
	 * @param delim
	 * @return
	 ***************************************************************************/
	public static String substringAfter(String string, String delim) {
		int i = string.indexOf(delim);
		if (i < 0)
			return string;
		else
			return string.substring(i + delim.length());
	}

	/****************************************************************************
	 * Returns the substring before the delimeiter or the string if it does not
	 * contain the delimiter.
	 * 
	 * @param string
	 * @param delim
	 * @return
	 ***************************************************************************/
	public static String substringBefore(String string, String delim) {
		int i = string.indexOf(delim);
		if (i < 0)
			return string;
		return string.substring(0, i);
	}

	/****************************************************************************
	 *  
	 ***************************************************************************/
	public static boolean isNullOrEmptyString(String s) {
		return (s == null || s.equals(""));
	}

	/****************************************************************************
	 *  
	 ***************************************************************************/
	public static boolean notNullOrEmpty(String s) {
		boolean nne = !(s == null || s.equals(""));
		return nne;
	}

	/****************************************************************************
	 * Returns true if the first argument string contains the second argument
	 * string.
	 ***************************************************************************/
	public static boolean contains(String s, String t) {
		if (s.indexOf(t) >= 0)
			return true;
		else
			return false;
	}

	/****************************************************************************
	 * Returns the substring after the last index of the delimiter
	 ***************************************************************************/
	public static String substringAfterLast(String string, String delim) {
		int i = string.lastIndexOf(delim);
		if (i < 0)
			return string;
		return string.substring(i + delim.length());
	}
	
	/**
	 * 
	 */
	public static String substringBeforeLast(String string, String delim) {
		
		int i = string.lastIndexOf(delim);
		if ( i < 0 )
			return string;
		
		return string.substring(0, i);
	}

	/**
	 * 
	 */
	public static String pluralize(String string) {
		String plural = "";
		if (string.endsWith("y")) {
			//just like teacher said... drp the y and add ies.
			plural = string.substring(0, string.length()-1) + "ies";
		} else if (string.endsWith("es")){
			plural = string; //what the plural of glasses?
		}
		else if (string.endsWith("s")){
			plural = string+"es"; //what the plural of glasses?
		}
		else {
			plural = string + "s";
		}

		return plural;
	}
	
	/**
	 * 
	 */
	public static boolean isNumeric(String string) {

		return string.matches("^\\d+$");
	}
	
	/**
	 * 
	 */
	public static boolean matchesPattern(String str, String regEx) {
		
		// Allow empty strings
		if ( str.equals("") )
			return true;
		
		// Check string against regular expression
		return StringUtils.notNullOrEmpty(regEx) && Pattern.matches(regEx, str);		
	}
}
